==> jc-1.4.0.tar.gz: java/awt/PageAttributes__24OrientationRequestedType.h <==
// public final class java.awt.PageAttributes$OrientationRequestedType

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class f24f2e12ea2678dd java_awt_PageAttributes__24OrientationRequestedType
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_AttributeValue

#include "java/awt/AttributeValue.h"

#ifndef _JC_java_awt_PageAttributes__24OrientationRequestedType_H_
#define _JC_java_awt_PageAttributes__24OrientationRequestedType_H_

// Forward structure declarations
struct _jc_java_awt_PageAttributes__24OrientationRequestedType$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_PageAttributes__24OrientationRequestedType$sub_refs	_jc_java_awt_PageAttributes__24OrientationRequestedType$sub_refs;
typedef struct _jc_java_awt_PageAttributes__24OrientationRequestedType$sub_nonrefs	_jc_java_awt_PageAttributes__24OrientationRequestedType$sub_nonrefs;
typedef struct _jc_java_awt_PageAttributes__24OrientationRequestedType$refs	_jc_java_awt_PageAttributes__24OrientationRequestedType$refs;
typedef struct _jc_java_awt_PageAttributes__24OrientationRequestedType$nonrefs	_jc_java_awt_PageAttributes__24OrientationRequestedType$nonrefs;
typedef struct _jc_java_awt_PageAttributes__24OrientationRequestedType$object	_jc_java_awt_PageAttributes__24OrientationRequestedType$object;

typedef struct _jc_java_awt_PageAttributes__24OrientationRequestedType$fields_struct	_jc_java_awt_PageAttributes__24OrientationRequestedType$fields_struct;
typedef const struct _jc_java_awt_PageAttributes__24OrientationRequestedType$vmethods	_jc_java_awt_PageAttributes__24OrientationRequestedType$vmethods;
typedef const struct _jc_java_awt_PageAttributes__24OrientationRequestedType$vtable	_jc_java_awt_PageAttributes__24OrientationRequestedType$vtable;
typedef const struct _jc_java_awt_PageAttributes__24OrientationRequestedType$vtype	_jc_java_awt_PageAttributes__24OrientationRequestedType$vtype;

// Class fields structure
struct _jc_java_awt_PageAttributes__24OrientationRequestedType$fields_struct {
	struct _jc_java_awt_PageAttributes__24OrientationRequestedType$object	*LANDSCAPE;
	_jc_object_array	*NAMES;
	struct _jc_java_awt_PageAttributes__24OrientationRequestedType$object	*PORTRAIT;
};
extern _jc_java_awt_PageAttributes__24OrientationRequestedType$fields_struct _jc_java_awt_PageAttributes__24OrientationRequestedType$class_fields;

// Constructors
extern void _jc_java_awt_PageAttributes__24OrientationRequestedType$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_PageAttributes__24OrientationRequestedType$object *, jint);

// Static methods
extern void _jc_java_awt_PageAttributes__24OrientationRequestedType$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_awt_PageAttributes__24OrientationRequestedType$vmethods {
};

// Vtable
struct _jc_java_awt_PageAttributes__24OrientationRequestedType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AttributeValue$vmethods	java_awt_AttributeValue;
	_jc_java_awt_PageAttributes__24OrientationRequestedType$vmethods	java_awt_PageAttributes__24OrientationRequestedType;
};

// Vtype
struct _jc_java_awt_PageAttributes__24OrientationRequestedType$vtype {
	_jc_type			type;
	_jc_java_awt_PageAttributes__24OrientationRequestedType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_PageAttributes__24OrientationRequestedType$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_PageAttributes__24OrientationRequestedType$refs {
    _jc_java_awt_PageAttributes__24OrientationRequestedType$sub_refs	java_awt_PageAttributes__24OrientationRequestedType;
    _jc_java_awt_AttributeValue$sub_refs	java_awt_AttributeValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_PageAttributes__24OrientationRequestedType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_PageAttributes__24OrientationRequestedType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AttributeValue$sub_nonrefs	java_awt_AttributeValue;
    _jc_java_awt_PageAttributes__24OrientationRequestedType$sub_nonrefs	java_awt_PageAttributes__24OrientationRequestedType;
};

// Object instance structure
struct _jc_java_awt_PageAttributes__24OrientationRequestedType$object {
	_jc_java_awt_PageAttributes__24OrientationRequestedType$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_PageAttributes__24OrientationRequestedType$vtype	*vtype;
	_jc_java_awt_PageAttributes__24OrientationRequestedType$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_PageAttributes__24OrientationRequestedType$vtype _jc_java_awt_PageAttributes__24OrientationRequestedType$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_PageAttributes__24OrientationRequestedType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_PageAttributes__24OrientationRequestedType$class_object;

#endif	/* _JC_java_awt_PageAttributes__24OrientationRequestedType_H_ */

==> jc-1.4.6.tar.gz: java/awt/PageAttributes__24OrientationRequestedType.h <==
// public final class java.awt.PageAttributes$OrientationRequestedType

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class f24f2e12ea2678dd java_awt_PageAttributes__24OrientationRequestedType
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_AttributeValue

#include "java/awt/AttributeValue.h"

#ifndef _JC_java_awt_PageAttributes__24OrientationRequestedType_H_
#define _JC_java_awt_PageAttributes__24OrientationRequestedType_H_

// Forward structure declarations
struct _jc_java_awt_PageAttributes__24OrientationRequestedType$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_PageAttributes__24OrientationRequestedType$sub_refs	_jc_java_awt_PageAttributes__24OrientationRequestedType$sub_refs;
typedef struct _jc_java_awt_PageAttributes__24OrientationRequestedType$sub_nonrefs	_jc_java_awt_PageAttributes__24OrientationRequestedType$sub_nonrefs;
typedef struct _jc_java_awt_PageAttributes__24OrientationRequestedType$refs	_jc_java_awt_PageAttributes__24OrientationRequestedType$refs;
typedef struct _jc_java_awt_PageAttributes__24OrientationRequestedType$nonrefs	_jc_java_awt_PageAttributes__24OrientationRequestedType$nonrefs;
typedef struct _jc_java_awt_PageAttributes__24OrientationRequestedType$object	_jc_java_awt_PageAttributes__24OrientationRequestedType$object;

typedef struct _jc_java_awt_PageAttributes__24OrientationRequestedType$fields_struct	_jc_java_awt_PageAttributes__24OrientationRequestedType$fields_struct;
typedef const struct _jc_java_awt_PageAttributes__24OrientationRequestedType$vmethods	_jc_java_awt_PageAttributes__24OrientationRequestedType$vmethods;
typedef const struct _jc_java_awt_PageAttributes__24OrientationRequestedType$vtable	_jc_java_awt_PageAttributes__24OrientationRequestedType$vtable;
typedef const struct _jc_java_awt_PageAttributes__24OrientationRequestedType$vtype	_jc_java_awt_PageAttributes__24OrientationRequestedType$vtype;

// Class fields structure
struct _jc_java_awt_PageAttributes__24OrientationRequestedType$fields_struct {
	struct _jc_java_awt_PageAttributes__24OrientationRequestedType$object	*LANDSCAPE;
	_jc_object_array	*NAMES;
	struct _jc_java_awt_PageAttributes__24OrientationRequestedType$object	*PORTRAIT;
};
extern _jc_java_awt_PageAttributes__24OrientationRequestedType$fields_struct _jc_java_awt_PageAttributes__24OrientationRequestedType$class_fields;

// Constructors
extern void _jc_java_awt_PageAttributes__24OrientationRequestedType$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_PageAttributes__24OrientationRequestedType$object *, jint) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_awt_PageAttributes__24OrientationRequestedType$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_PageAttributes__24OrientationRequestedType$vmethods {
};

// Vtable
struct _jc_java_awt_PageAttributes__24OrientationRequestedType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AttributeValue$vmethods	java_awt_AttributeValue;
	_jc_java_awt_PageAttributes__24OrientationRequestedType$vmethods	java_awt_PageAttributes__24OrientationRequestedType;
};

// Vtype
struct _jc_java_awt_PageAttributes__24OrientationRequestedType$vtype {
	_jc_type			type;
	_jc_java_awt_PageAttributes__24OrientationRequestedType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_PageAttributes__24OrientationRequestedType$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_PageAttributes__24OrientationRequestedType$refs {
    _jc_java_awt_PageAttributes__24OrientationRequestedType$sub_refs	java_awt_PageAttributes__24OrientationRequestedType;
    _jc_java_awt_AttributeValue$sub_refs	java_awt_AttributeValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_PageAttributes__24OrientationRequestedType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_PageAttributes__24OrientationRequestedType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AttributeValue$sub_nonrefs	java_awt_AttributeValue;
    _jc_java_awt_PageAttributes__24OrientationRequestedType$sub_nonrefs	java_awt_PageAttributes__24OrientationRequestedType;
};

// Object instance structure
struct _jc_java_awt_PageAttributes__24OrientationRequestedType$object {
	_jc_java_awt_PageAttributes__24OrientationRequestedType$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_PageAttributes__24OrientationRequestedType$vtype	*vtype;
	_jc_java_awt_PageAttributes__24OrientationRequestedType$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_PageAttributes__24OrientationRequestedType$vtype _jc_java_awt_PageAttributes__24OrientationRequestedType$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_PageAttributes__24OrientationRequestedType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_PageAttributes__24OrientationRequestedType$class_object;

#endif	/* _JC_java_awt_PageAttributes__24OrientationRequestedType_H_ */
